@@ -4,9 +4,9 @@ use warnings;
 
 package Dancer2::Session::Cookie;
 # ABSTRACT: Dancer 2 session storage in secure cookies
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
-use Session::Storage::Secure ();
+use Session::Storage::Secure 0.007 ();
 
 use Moo;
 use Dancer2::Core::Types;
@@ -97,7 +97,7 @@ Dancer2::Session::Cookie - Dancer 2 session storage in secure cookies
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
